@@ -30,6 +30,7 @@ from ansys.mapdl.core.errors import MapdlInvalidRoutineError, MapdlRuntimeError
 from ansys.mapdl.core.inline_functions import Query
 from ansys.mapdl.core.misc import (
     last_created,
+    load_file,
     random_string,
     run_as_prep7,
     supress_logging,
@@ -1618,9 +1619,9 @@ class _MapdlCore(Commands):
         self._log_filehandler = logging.FileHandler(filepath, mode=mode)
         self._log_filehandler.setFormatter(logging.Formatter(formatstr))
         if isinstance(level, str):
-            level = level.uppder()
+            level = level.upper()
         self._log_filehandler.setLevel(level)
-        self._log.addHandler(self._log_filehandler)
+        self._log.logger.addHandler(self._log_filehandler)
         self._log.info("Added file handler at %s", filepath)
 
     def remove_file_handler(self):
@@ -2890,3 +2891,40 @@ class _MapdlCore(Commands):
                 "Hence its use is not recommended outside them."
                 "You might run in unexpected behaviours, for example, parameters not being show in `mapdl.parameters`."
             )
+
+    @wraps(Commands.mpread)
+    def mpread(self, fname="", ext="", lib="", **kwargs):
+        if lib:
+            raise NotImplementedError(
+                "The option 'lib' is not supported by the MAPDL gRPC server."
+            )
+
+        fname_ = fname + "." + ext
+        fname = load_file(self, fname_)
+        self._log.info("Bypassing 'MPREAD' with 'INPUT'.")
+        return self.input(fname)
+
+    @wraps(Commands.mpwrite)
+    def mpwrite(
+        self,
+        fname="",
+        ext="",
+        lib="",
+        mat="",
+        download_file=False,
+        progress_bar=True,
+        **kwargs,
+    ):
+        fname_ = fname + "." + ext
+        if not self._local:
+            if os.path.dirname(fname_):
+                raise IOError(
+                    "Only writing files to the MAPDL working directory is allowed. "
+                    f"The supplied path {fname_} is not allowed."
+                )
+
+        output = super().mpwrite(fname, ext, lib, mat, **kwargs)
+        if download_file:
+            self.download(os.path.basename(fname_), progress_bar=progress_bar)
+
+        return output
